<div align="center">

<img src="https://raw.githubusercontent.com/ValkyrieSystems/sarkit/main/docs/source/_static/sarkit_logo.png" width=200>

</div>

**sarkit-convert** is a Python library for converting SAR data to standard formats.

## License
This repository is licensed under the [MIT license](./LICENSE).

A few tips for getting started using [PDM](https://pdm-project.org/en/latest/) are below:


```shell
$ pdm install -G:all  # install SARkit-convert with optional & dev dependencies
$ pdm run nox  # run lint and tests
```
